@@ -242,12 +242,12 @@ def root():
     workTree = [n.a_blob.path for n in allModified if n.a_blob.path.split('/')[0] == '_'.join(sourceLang.split('-')).lower()] + untrackedSrc
 
 @root.command()
-@click.option('-k', '--key', type=str)
+@click.option('-k', '--apikey', type=str)
 @click.option('-s', '--source', type=str)
 @click.option('-t', '--target', type=list)
 def config():
     """Show and set configuration"""
-    print(key)
+    print(apikey)
     print(source)
     print(target)
     exit()
